:py:mod:`byma.iteral.stationary.Stationary`
===========================================

.. py:module:: byma.iteral.stationary.Stationary


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.stationary.Stationary.Stationary




.. py:class:: Stationary


   Defines default options for the Stationary method


